require "faraday"
require "faraday_middleware"

module SmartHR
  class Client
    require "smarthr/client/bank_account_setting_methods"
    require "smarthr/client/biz_establishment_methods"
    require "smarthr/client/crew_custom_field_template_group_methods"
    require "smarthr/client/crew_custom_field_template_methods"
    require "smarthr/client/crew_input_form_method"
    require "smarthr/client/crew_methods"
    require "smarthr/client/department_methods"
    require "smarthr/client/dependent_methods"
    require "smarthr/client/dependent_relation_methods"
    require "smarthr/client/employment_type_methods"
    require "smarthr/client/job_title_methods"
    require "smarthr/client/mail_format_methods"
    require "smarthr/client/payment_period_methods"
    require "smarthr/client/user_methods"
    require "smarthr/client/webhook_methods"

    include Converter
    include BankAccountSettingMethods
    include BizEstablishmentMethods
    include CrewCustomFieldTemplateGroupMethods
    include CrewCustomFieldTemplateMethods
    include CrewInputFormMethods
    include CrewMethods
    include DepartmentMethods
    include DependentMethods
    include DependentRelationMethods
    include EmploymentTypeMethods
    include JobTitleMethods
    include MailFormatMethods
    include PaymentPeriodMethods
    include UserMethods
    include WebhookMethods

    def initialize(tenant_id: nil, access_token: nil, sandbox: false, header: {}, api_version: 'v1')
      raise unless tenant_id
      raise unless access_token

      url = sprintf(sandbox ? "https://%s.daruma.space/api/" : "https://%s.smarthr.jp/api/", tenant_id)
      header.merge!({
        "User-Agent" => "SmartHR/#{api_version} RubyBinding/#{SmartHR::VERSION}",
        "Authorization" => "Bearer #{access_token}"
      })

      @conn = Faraday.new(url, headers: header) do |builder|
        builder.request :url_encoded
        builder.response :mashify
        builder.response :json
        builder.adapter Faraday.default_adapter
      end
      @api_version = api_version
    end

    def handle_response(response)
      case response.status
      when 200..299
        response.body
      else
        puts response.status
        puts response.body
        raise SmartHR::Error.from_response(response.status, response.body)
      end
    end

    Faraday::Connection::METHODS.each do |method|
      define_method(method) do |url, args = {}, &block|
        faraday_errors =
          if Gem::Version.create(Faraday::VERSION) >= Gem::Version.create("1.0.0")
            [Faraday::ClientError, Faraday::ServerError]
          else
            [Faraday::Error::ClientError]
          end

        begin
          response = @conn.__send__(method, @api_version + url, hash_compact(args))
        rescue *faraday_errors => e
          raise SmartHR::APIConnectionError.faraday_error(e)
        end
        payload = handle_response(response)
        block.call(payload, response.headers) if block
        payload
      end
    end
  end
end
