module SmartHR::Client::DepartmentMethods
  # Delete the department
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E9%83%A8%E7%BD%B2/deleteV1DepartmentsId
  #
  # @param id [String]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  def destroy_department(id:, &block)
    delete("/departments/#{id}", &block)
  end

  # Get the department
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E9%83%A8%E7%BD%B2/getV1DepartmentsId
  #
  # @param id [String]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def find_department(id:, &block)
    get("/departments/#{id}", &block)
  end

  # Change the data of the specified department
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E9%83%A8%E7%BD%B2/patchV1DepartmentsId
  #
  # @param id   [String]
  # @param body [Hash]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def update_department(id:, body:, &block)
    patch("/departments/#{id}", body, &block)
  end

  # Get the list of departments
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E9%83%A8%E7%BD%B2/getV1Departments
  #
  # @param page     [Integer]
  # @param per_page [Integer]
  # @param code     [String]
  # @param sort     [String]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Array<Hashie::Mash>] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Array<Hashie::Mash>]
  def get_departments(page: 1, per_page: 10, code: nil, sort: nil, &block)
    get("/departments",
      page: page,
      per_page: per_page,
      code: code,
      sort: sort,
      &block
    )
  end

  # Create a new department
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E9%83%A8%E7%BD%B2/postV1Departments
  #
  # @param body [Hash]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def create_department(body:, &block)
    post("/departments", body, &block)
  end
end
