module SmartHR::Client::DependentMethods
  # Delete the crew dependent
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%AE%B6%E6%97%8F%E6%83%85%E5%A0%B1/deleteV1CrewsCrewIdDependentsId
  #
  # @param crew_id [String]
  # @param id      [String]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  def destroy_crew_dependent(crew_id:, id:, &block)
    delete("/crews/#{crew_id}/dependents/#{id}", &block)
  end

  # Get the crew dependent
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%AE%B6%E6%97%8F%E6%83%85%E5%A0%B1/getV1CrewsCrewIdDependentsId
  #
  # @param crew_id [String]
  # @param id      [String]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def find_crew_dependent(crew_id:, id:, &block)
    get("/crews/#{crew_id}/dependents/#{id}", &block)
  end

  # Change the data of the specified crew dependent
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%AE%B6%E6%97%8F%E6%83%85%E5%A0%B1/patchV1CrewsCrewIdDependentsId
  #
  # @param crew_id [String]
  # @param id      [String]
  # @param body    [Hash]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def update_crew_dependent(crew_id:, id:, body:, &block)
    patch("/crews/#{crew_id}/dependents/#{id}", body, &block)
  end

  # Get the list of crew dependents
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%AE%B6%E6%97%8F%E6%83%85%E5%A0%B1/getV1CrewsCrewIdDependents
  #
  # @param crew_id  [String]
  # @param page     [Integer]
  # @param per_page [Integer]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Array<Hashie::Mash>] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Array<Hashie::Mash>]
  def get_crew_dependents(crew_id:, page: 1, per_page: 10, &block)
    get("/crews/#{crew_id}/dependents",
      page: page,
      per_page: per_page,
      &block
    )
  end

  # Create a new crew dependent
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%AE%B6%E6%97%8F%E6%83%85%E5%A0%B1/postV1CrewsCrewIdDependents
  #
  # @param crew_id [String]
  # @param body    [Hash]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def create_crew_dependent(crew_id:, body:, &block)
    post("/crews/#{crew_id}/dependents", body, &block)
  end
end
