module SmartHR::Client::JobTitleMethods
  # Delete the job title
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%BD%B9%E8%81%B7/deleteV1JobTitlesId
  #
  # @param id [String]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  def destroy_job_title(id:, &block)
    delete("/job_titles/#{id}", &block)
  end

  # Get the job title
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%BD%B9%E8%81%B7/getV1JobTitlesId
  #
  # @param id [String]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def find_job_title(id:, &block)
    get("/job_titles/#{id}", &block)
  end

  # Change the data of the specified job title
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%BD%B9%E8%81%B7/patchV1JobTitlesId
  #
  # @param id   [String]
  # @param body [Hash]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def update_job_title(id:, body:, &block)
    patch("/job_titles/#{id}", body, &block)
  end

  # Get the list of job titles
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%BD%B9%E8%81%B7/getV1JobTitles
  #
  # @param page     [Integer]
  # @param per_page [Integer]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Array<Hashie::Mash>] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Array<Hashie::Mash>]
  def get_job_titles(page: 1, per_page: 10, &block)
    get("/job_titles",
      page: page,
      per_page: per_page,
      &block
    )
  end

  # Create a new job title
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%BD%B9%E8%81%B7/postV1JobTitles
  #
  # @param body [Hash]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def create_job_title(body:, &block)
    post("/job_titles", body, &block)
  end
end
