module SmartHR::Client::WebhookMethods
  # Delete the webhook
  #
  # @see https://developer.smarthr.jp/api/index.html#!/Webhook/deleteV1WebhooksId
  #
  # @param id [String]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  def destroy_webhook(id:, &block)
    delete("/webhooks/#{id}", &block)
  end

  # Get the webhook
  #
  # @see https://developer.smarthr.jp/api/index.html#!/Webhook/getV1WebhooksId
  #
  # @param id [String]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def find_webhook(id:, &block)
    get("/webhooks/#{id}", &block)
  end

  # Change the data of the specified webhook
  #
  # @see https://developer.smarthr.jp/api/index.html#!/Webhook/patchV1WebhooksId
  #
  # @param id   [String]
  # @param body [Hash]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def update_webhook(id:, body:, &block)
    patch("/webhooks/#{id}", body, &block)
  end

  # Get the list of webhooks
  #
  # @see https://developer.smarthr.jp/api/index.html#!/Webhook/getV1Webhooks
  #
  # @param page     [Integer]
  # @param per_page [Integer]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Array<Hashie::Mash>] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Array<Hashie::Mash>]
  def get_webhooks(page: 1, per_page: 10, &block)
    get("/webhooks",
      page: page,
      per_page: per_page,
      &block
    )
  end

  # Create a new webhook
  #
  # @see https://developer.smarthr.jp/api/index.html#!/Webhook/postV1Webhooks
  #
  # @param body [Hash]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def create_webhook(body:, &block)
    post("/webhooks", body, &block)
  end
end
